summaryrefslogtreecommitdiffstats
path: root/kunittest/runner.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kunittest/runner.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kunittest/runner.cpp')
-rw-r--r--kunittest/runner.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kunittest/runner.cpp b/kunittest/runner.cpp
index 580d451b8..f0eb5c4df 100644
--- a/kunittest/runner.cpp
+++ b/kunittest/runner.cpp
@@ -57,7 +57,7 @@ namespace KUnitTest
TQDir dir(folder, "kunittest_*.la");
// Add the folder to the "module" resource such that the KLibLoader can
// find the modules in this folder.
KGlobal::dirs()->addResourceDir("module", folder);
kdDebug() << "Looking in folder: " << dir.absPath() << endl;
@@ -203,7 +203,7 @@ namespace KUnitTest
void Runner::runTest(const char *name)
{
- Tester *test = m_registry.find(name);
+ Tester *test = m_registry.tqfind(name);
if ( test == 0L ) return;
if ( s_debugCapturingEnabled )
@@ -57,7 +57,7 @@ namespace KUnitTest
TQDir dir(folder, "kunittest_*.la");
// Add the folder to the "module" resource such that the KLibLoader can
- // find the modules in this folder.
+ // tqfind the modules in this folder.
KGlobal::dirs()->addResourceDir("module", folder);
kdDebug() << "Looking in folder: " << dir.absPath() << endl;